@@ -9,7 +9,9 @@ MainWindow::MainWindow(QWidget *parent) :
     ui(new Ui::MainWindow)
 {
     ui->setupUi(this);
-
+settings=new QSettings();
+bios_path=settings->value("bios_path","/home/user/MyDocs/").toString();
+ rom_path=settings->value("rom_path","/home/user/MyDocs/").toString();
 
     this->setAttribute(Qt::WA_Maemo5StackedWindow);
     cfg=new options(this);
@@ -75,6 +77,8 @@ myProcess->startDetached("/opt/maemo/usr/games/"+current_core, args,"/home/user/
 
 void MainWindow::currentRowChanged ( int currentRow ){
     if (ui->listWidget->currentRow()!=-1){
+        game="";
+        cfg->load_cfg();
         game=ui->listWidget->currentItem()->text();
         cfg->load_cfg();
     }
@@ -95,8 +99,33 @@ cfg->show();
 
 void MainWindow::gui_cfg() // Настройки поведения GUI - rom dir,bios dir,exit after start
 {
+    QDialog *dlg=new QDialog(this);
+    QGridLayout *lay=new QGridLayout(dlg);
+    QPushButton *btn1=new QPushButton(tr("Rom directory"),dlg);
+    QPushButton *btn2=new QPushButton(tr("Bios directory"),dlg);
+    connect (btn1,SIGNAL(clicked()),this,SLOT(set_rom_dir()));
+    connect (btn2,SIGNAL(clicked()),this,SLOT(set_bios_dir()));
+    lay->addWidget(btn1,1,0);
+    lay->addWidget(btn2 ,2,0);
+    dlg->exec();
+    dlg=NULL;
+}
+
+void MainWindow::set_rom_dir(){
+    QString dir=QFileDialog::getExistingDirectory(this,tr("ROM Directory"),"/home/user/MyDocs/");
+    QString rom_path=dir;
+    settings->setValue("rom_path",rom_path);
+
 
 }
+void MainWindow::set_bios_dir(){
+    QString dir=QFileDialog::getExistingDirectory(this,tr("BIOS Directory"),"/home/user/MyDocs/");
+    QString bios_path=dir;
+    settings->setValue("bios_path",bios_path);
+
+
+}
+
 void MainWindow::open_help() // Открытие страницы FAQ
 {
     QDesktopServices::openUrl(QUrl("http://maemo.team16.ru/index.php?page=7"));
